@@ -38,10 +38,11 @@ pub fn execute_hooks(
     hooks: &[String],
     allow_commands: bool,
     silent: bool,
-) -> Result<()> {
+) -> Result<liquid::Object> {
     let liquid_object = Rc::new(RefCell::new(liquid_object));
-    let engine = create_rhai_engine(dir, liquid_object, allow_commands, silent);
-    evaluate_scripts(dir, hooks, engine)
+    let engine = create_rhai_engine(dir, liquid_object.clone(), allow_commands, silent);
+    evaluate_scripts(dir, hooks, engine)?;
+    Ok(liquid_object.take())
 }
 
 fn evaluate_scripts(template_dir: &Path, scripts: &[String], engine: rhai::Engine) -> Result<()> {
@@ -74,17 +75,18 @@ pub fn evaluate_script<T: Clone + 'static>(
 
     #[allow(deprecated)]
     conditional_evaluation_engine.on_var({
-        move |name, _, _| match liquid_object.get(name) {
-            Some(value) => Ok(value.as_view().as_scalar().map(|scalar| {
-                scalar.to_bool().map_or_else(
-                    || {
-                        let v = scalar.to_kstr();
-                        v.as_str().into()
-                    },
-                    |v| v.into(),
-                )
-            })),
-            None => Ok(None),
+        move |name, _, _| {
+            liquid_object.get(name).map_or(Ok(None), |value| {
+                Ok(value.as_view().as_scalar().map(|scalar| {
+                    scalar.to_bool().map_or_else(
+                        || {
+                            let v = scalar.to_kstr();
+                            v.as_str().into()
+                        },
+                        |v| v.into(),
+                    )
+                }))
+            })
         }
     });
 
@@ -124,7 +126,7 @@ fn create_rhai_engine(
     engine.register_fn("to_upper_camel_case", |str: &str| str.to_upper_camel_case());
 
     // other free-standing functions
-    engine.register_result_fn("abort", |error: &str| -> HookResult<String> {
+    engine.register_fn("abort", |error: &str| -> HookResult<String> {
         Err(error.into())
     });
 
